==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ScatterContourSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ValueBrushScaleDescriptionMetadata } from "./ValueBrushScaleDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { ScatterTriangulationSeriesDescriptionMetadata } from "./ScatterTriangulationSeriesDescriptionMetadata";
import { ScatterContourSeriesDescription } from "./ScatterContourSeriesDescription";
/**
 * @hidden
 */
export let ScatterContourSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterContourSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterContourSeriesDescriptionMetadata.a == null) {
                ScatterContourSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterContourSeriesDescriptionMetadata.c(ScatterContourSeriesDescriptionMetadata.a);
            }
            if (a.j(ScatterContourSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(ScatterContourSeriesDescriptionMetadata.a);
            ValueBrushScaleDescriptionMetadata.d(a);
            ContourValueResolverDescriptionMetadata.d(a);
        }
        static c(a) {
            ScatterTriangulationSeriesDescriptionMetadata.c(a);
            a.item("ValueMemberPath", "String");
            a.item("ValueMemberAsLegendLabel", "String");
            a.item("ValueMemberAsLegendUnit", "String");
            a.item("FillScale", "ExportedType:ValueBrushScale");
            a.item("ActualFillScale", "ExportedType:ValueBrushScale");
            a.item("ValueResolver", "ExportedType:ContourValueResolver");
        }
        static d(a) {
            ScatterContourSeriesDescriptionMetadata.b(a);
            a.aa("ScatterContourSeries", () => new ScatterContourSeriesDescription());
            a.z("ScatterContourSeries", ScatterContourSeriesDescriptionMetadata.a);
        }
    }
    ScatterContourSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ScatterContourSeriesDescriptionMetadata, 'ScatterContourSeriesDescriptionMetadata');
    ScatterContourSeriesDescriptionMetadata.a = null;
    return ScatterContourSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ScatterContourSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ValueBrushScaleDescriptionMetadata } from "./ValueBrushScaleDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { ScatterTriangulationSeriesDescriptionMetadata } from "./ScatterTriangulationSeriesDescriptionMetadata";
import { ScatterContourSeriesDescription } from "./ScatterContourSeriesDescription";
/**
 * @hidden
 */
export let ScatterContourSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterContourSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterContourSeriesDescriptionMetadata.a == null) {
                ScatterContourSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterContourSeriesDescriptionMetadata.c(ScatterContourSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterContourSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(ScatterContourSeriesDescriptionMetadata.a);
            ValueBrushScaleDescriptionMetadata.d(a);
            ContourValueResolverDescriptionMetadata.d(a);
        }
        static c(a) {
            ScatterTriangulationSeriesDescriptionMetadata.c(a);
            a.item("ValueMemberPath", "String");
            a.item("ValueMemberAsLegendLabel", "String");
            a.item("ValueMemberAsLegendUnit", "String");
            a.item("FillScale", "ExportedType:ValueBrushScale");
            a.item("ActualFillScale", "ExportedType:ValueBrushScale");
            a.item("ValueResolver", "ExportedType:ContourValueResolver");
        }
        static d(a) {
            ScatterContourSeriesDescriptionMetadata.b(a);
            a.ac("ScatterContourSeries", () => new ScatterContourSeriesDescription());
            a.ab("ScatterContourSeries", ScatterContourSeriesDescriptionMetadata.a);
        }
    }
    ScatterContourSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ScatterContourSeriesDescriptionMetadata, 'ScatterContourSeriesDescriptionMetadata');
    ScatterContourSeriesDescriptionMetadata.a = null;
    return ScatterContourSeriesDescriptionMetadata;
})();
